<template>
  <div class="process-panel">
    <div class="comment-box">
      <div class="wrap-left">
        <!-- 意见 -->
        <div>
          <mt-field 
            class="opinion"
            :placeholder="$t('fillComments')"
            maxlength="140"
            type="textarea" 
            rows="5" 
            v-model="attitude">
          </mt-field>
        </div>
      </div>
      <!-- 工具操作（右边） -->
      <div class="wrap-right-btn">
        <span @click="runBeforeAction" class="sign primary">
          {{$t('confirm')}}
        </span>
      </div>
    </div>
  </div>
</template>

<script>
import { Toast } from 'mint-ui';
export default {
  props: [
    "act", 
    "docIds", 
    "formId", 
    "viewId"
  ],
  data: function() {
    return {
      attitude: "",
    };
  },
  created() {
    
  },

  mounted() {
  
  },
  methods: {
    runBeforeAction(){
	  let act = this.act
      let formData = {
        docId: "",
        document: {},
        formId: this.formId,
        parentId: "",
        templateForm: "",
        viewId: this.viewId,
        _selects: this.docIds,
      }
      let divId = this.act.id;
      this.$api.runBeforeActionScript(this.$root.appid, divId, formData, {
        onSucess: response => {
          if(response.data.data) {
            let resData = response.data.data;
            let errmsg = resData.content;
            if(resData.changedField) {
              Toast({
                message: errmsg,
                iconClass: 'icon icon-success'
              });
            }else {
              if(resData.type && resData.type === 1) {
                Toast({
                  message: errmsg,
                  iconClass: 'icon icon-success'
                });
              }else if(resData.type && resData.type === 16) {
                Toast(errmsg);
              }else if(resData.type && resData.type === 32) {
                MessageBox.confirm('', {
                  title:this.$t('tip'),
                  message:errmsg,
                  confirmButtonText:this.$t('confirm'),
                  cancelButtonText: this.$t('cancel')
                }).then(() => { 
                  switch (act.type) {
                    case 2: //新建
                      this.doCreate(act);
                      break;
                    case 3: //删除
                      this.removeDocuments(act,docIds);
                      break;
                    case 18:
                      this.clearAllData(act);
                      break;
                    case 43: //跳转
                      this.jumpType(act);
                      break;
					case 20: //批量提交
                      this.onSubmit(act);
                      break;
                    default:
                      this.getTemplate(act);
                      break;
                  }
                }).catch(() =>{
                });
              }else {
                Toast(errmsg);
              }
            }
          }else {
            switch(act.type) {
              case 2: //新建
                this.doCreate(act);
                break;
              case 3: //删除
                this.removeDocuments(act,docIds);
                break;
              case 18:
                this.clearAllData(act);
                break;
              case 43: //跳转
                this.jumpType(act);
                break;
			  case 20: //批量提交
			    this.onSubmit(act);
			    break;
              default:
                this.getTemplate(act);
                break;
            }
          }




          if(response.data.errcode == 0 && response.data.data) {
            Toast(response.data.data.content);
          }else if(response.data.errcode == 0){
            this.onSubmit();
          }
        }
      });
    },

    //提交
    onSubmit() {
      let attitude = this.attitude;
      let appId = this.$root.appid;
      let doJson = {
        actId:this.act.id,
        attitude,
        docIds:this.docIds,
        limistStrList:'',
        remark: '',
      }
      this.$api.batchApprove(appId, doJson, {
        onSucess: response => {
          let status = ""
          if(response.data.errcode==0) {
            status = 'SUCCESS';
            this.runAfterAction();
            this.$emit("hideDialog",status)
            //this.$parent.$parent.$parent.$parent.$parent.closeThePopup(status);
            Toast({
              message: response.data.data.content,
              iconClass: 'fa fa-check fa-2x'
            });
          }else if(response.data.errcode==4001){
            status = 'ERROR';
            this.$emit("hideDialog",status)
            Toast({
              message: response.data.errmsg,
              iconClass: 'fa fa-close fa-2x'
            });
          }
        }
      });
    },

     //执行脚本后
    runAfterAction() {
      let formData = {
        docId: "",
        document: {},
        formId: this.formId,
        parentId: "",
        templateForm: "",
        viewId: this.viewId,
        _selects: this.docIds,
      }
      let appId = this.$root.appid;
      let divId = this.act.id;
      let docId = '';
      let parentId = '';
      let _templateForm = '';
      let _ = '';
      this.$api.runAfterActionScript(
        appId,
        divId,
        docId,
        this.viewId,
        this.formId,
        _templateForm,
        parentId,
        _,
        formData,
        this.act.type,//act.type
        {
          onSucess: response => {
            if (response.data.errcode == 0) {
              return true;
            }
          }
        }
      );
    },
  }
};
</script>
<style lang="scss">
  .wrap-right-btn {
    width:22%;
    float:left;
    position: absolute;
    bottom:0;
    right:8px;
    .sign {
      display: block;
      text-align: center;
      height:32px;
      width:78px;
      line-height: 32px;
      background:rgba(246,246,246,1);
      border-radius:4px;
      margin-bottom: 8px;
    }
    .primary {
        background:rgba(73,123,236,1);
        color:white;
    }
  }
</style>